﻿/** 
 * ---------------------------------------------------------------------------
 * Lapis SeedBox
 * ---------------------------------------------------------------------------
 * Rev.1  2017/07/08
 *   変更履歴
 *     種の取り出し方を変更
 */
using System;
using System.Collections;
using Server.Gumps;
using Server.Multis;
using Server.Network;
using Server.Engines.Plants;
using System.Collections.Generic;
using Server.ContextMenus;
using Server.Prompts;

namespace Server.Items
{
    class LapisSeedBox : Item, ISecurable

    {
        private SecureLevel m_Level;
        [CommandProperty(AccessLevel.GameMaster)]
        public SecureLevel Level
        {
            get
            {
                return this.m_Level;
            }
            set
            {
                this.m_Level = value;
            }
        }

        private static bool isDebug = false;
        /** 最大登録数 */
        private static readonly int MAX_COUNT = 1000;
        /** 種リスト */
        private ArrayList seedList = new ArrayList();
        /** 名前 */
        private String m_seedBoxName = "";

        [CommandProperty(AccessLevel.GameMaster)]
        public string seedBoxName
        {
            get
            {
                return this.m_seedBoxName;
            }
            set
            {
                this.m_seedBoxName = value;                
                this.InvalidateProperties();
            }
        }

        /** 現在表示しているメニューページ番号
         * 0：何も開いていない
         * 1：旧植物を開いている
         * 2：新植物を開いている
         * 3：盆栽を開いている
         */
        private int nowMenuPage = 0;

        /** 現在表示しているメインページ番号
         *  0：何も開いていない
         *  ----旧植物----(17種)
         *  1：ナデシコ
         *  2：ポピー
         *  3：マツユキソウ
         *  4：パピルス
         *  5：ユリ
         *  6：シロガネヨシ
         *  7：イグサ
         *  8：タロイモ
         *  9：シダ
         * 10：トックリラン
         * 11：小さいヤシ
         * 12：リュウゼツラン
         * 13：水草
         * 14：チトセラン
         * 15：ウチワサボテン
         * 16：タルサボテン
         * 17：ミツマタサボテン
         * ----新植物----(19種)
         *  1：サボテン
         *  2：左向きポップ
         *  3：右向きポップ
         *  4：スパイダーツリー
         *  5：ジキタリスの花
         *  6：オーフラーの花
         *  7：亜麻
         *  8：ポピー群
         *  9：マツユキソウ群
         * 10：ヒツジグサ
         * 11：ガマ
         * 12：サトウキビ
         * 13：生け垣
         * 14：高い生け垣
         * 15：西洋ネズ
         * 16：糸杉の木
         * 17：ねじれた糸杉
         * 18：カカオの木
         */
        private int nowPage = 0;

        /**
         * 左側メニューの植物タイプ
         */
        private PlantType[][] menuPlantList = new PlantType[][]
        {
            new PlantType[]
            {
            },
            // 旧植物
            new PlantType[]
            {
                PlantType.CampionFlowers,    // ナデシコ
                PlantType.Poppies,           // ポピー
                PlantType.Snowdrops,         // マツユキソウ,
                PlantType.Bulrushes,         // パピルス
                PlantType.Lilies,            // ユリ
                PlantType.PampasGrass,       // シロガネヨシ
                PlantType.Rushes,            // イグサ
                PlantType.ElephantEarPlant,  // タロイモ
                PlantType.Fern,              // シダ
                PlantType.PonytailPalm,      // トックリラン
                PlantType.SmallPalm,         // 小さいヤシ
                PlantType.CenturyPlant,      // リュウゼツラン
                PlantType.WaterPlant,        // 水草
                PlantType.SnakePlant,        // チトセラン
                PlantType.PricklyPearCactus, // ウチワサボテン
                PlantType.BarrelCactus,      // タルサボテン
                PlantType.TribarrelCactus    // ミツマタサボテン
            },
            // 新植物
            new PlantType[]
            {
               PlantType.Cactus,          // サボテン
               PlantType.HopsEast,        // 左向きポップ
               PlantType.HopsSouth,       // 右向きポップ
               PlantType.SpiderTree,      // スパイダーツリー
               PlantType.FoxgloveFlowers, // ジギタリスの花
               PlantType.OrfluerFlowers,  // オーフラーの花
               PlantType.FlaxFlowers,     // 亜麻
               PlantType.PoppyPatch,      // ポピー群
               PlantType.SnowdropPatch,   // マツユキソウ群
               PlantType.WaterLily,       // ヒツジグサ
               PlantType.Cattails,        // ガマ
               PlantType.SugarCanes,      // サトウキビ
               PlantType.HedgeShort,      // 生け垣
               PlantType.HedgeTall,       // 高い生け垣
               PlantType.JuniperBush,     // 西洋ネズ
               PlantType.CypressStraight, // 糸杉の木
               PlantType.CypressTwisted,  // ねじれた糸杉
               PlantType.CocoaTree        // カカオの木
            },
            // 盆栽
            new PlantType[]
            {
                PlantType.CommonGreenBonsai,   // 盆栽Ａ
                PlantType.CommonPinkBonsai,    // 盆栽Ｂ
                PlantType.UncommonGreenBonsai, // 盆栽Ｃ
                PlantType.UncommonPinkBonsai,  // 盆栽Ｄ
                PlantType.RareGreenBonsai,     // 盆栽Ｅ
                PlantType.RarePinkBonsai,      // 盆栽Ｆ
                PlantType.ExceptionalBonsai,   // 盆栽Ｇ
                PlantType.ExoticBonsai         // 盆栽Ｈ
            }
        };
        /**
         * 左側メニュー（日本語）
         * めんどくせええええローカライズされねえのか！
         */
        private String[][] menuPlantListName = new String[][]
        {
            new String[]
            {
            },
            new String[]
            {
                "ナデシコ","ポピー","マツユキソウ","パピルス","ユリ","シロガネヨシ","イグサ","タロイモ",
                "シダ","トックリラン","小さいヤシ","リュウゼツラン","水草","チトセラン","ウチワサボテン","タルサボテン","ミツマタサボテン"
            },
            new String[]
            {
                "サボテン","左向きポップ","右向きポップ","スパイダーツリー","ジギタリスの花","オーフラーの花","亜麻","ポピー群","マツユキソウ群",
                "ヒツジグサ","ガマ","サトウキビ","生け垣","高い生け垣","西洋ネズ","糸杉の木","ねじれた糸杉","カカオの木"
            },
            new String[]
            {
                "盆栽Ａ","盆栽Ｂ","盆栽Ｃ","盆栽Ｄ","盆栽Ｅ","盆栽Ｆ","盆栽Ｇ","盆栽Ｈ"
            }
        };

        private PlantHue[][] showColor = new PlantHue[][]
        {
            new PlantHue[]
            {
            },
            // 旧植物
            new PlantHue[]
            {
                PlantHue.Plain,
                PlantHue.Red, PlantHue.Blue, PlantHue.Yellow, PlantHue.Purple, PlantHue.Green, PlantHue.Orange,
                PlantHue.BrightRed, PlantHue.BrightBlue, PlantHue.BrightYellow, PlantHue.BrightPurple, PlantHue.BrightGreen, PlantHue.BrightOrange,
                PlantHue.Black, PlantHue.White, PlantHue.Pink, PlantHue.Magenta, PlantHue.Aqua, PlantHue.FireRed
            },
            // 新植物（ラピス仕様に合わせる）
            new PlantHue[]
            {
                PlantHue.Plain,
                PlantHue.Black, PlantHue.White, PlantHue.Pink, PlantHue.Magenta, PlantHue.Aqua, PlantHue.FireRed
            },
            // 盆栽
            new PlantHue[]
            {
                PlantHue.Plain
            }
        };

        [Constructable]
        public LapisSeedBox()
                : base(0x4B58)
        {
            this.Weight = 1.0;
            this.LootType = LootType.Blessed;
            this.Name = "ラピス民のSeedBox";
            this.m_Level = SecureLevel.Owner;
            if (isDebug)
            {
                for (int i = 0; i < MAX_COUNT; i++)
                {
                    switch (Utility.Random(3))
                    {
                        case 0:
                            debugMakeDefault();
                            break;
                        case 1:
                            debugMakePeculiar();
                            break;
                        default:
                            debugMakeBonsai();
                            break;
                    }
                }
            }
            for (int i = 0; i < 100; i++)
            {
                int aaa = test1();
                int bbb = test2();
                Console.WriteLine("test1=" + aaa + " test2=" + bbb);
            }
        }
        public int test1()
        {
            
            {
                switch (Utility.Random(2))
                {
                    default:
                    case 0: return 0;
                    case 1: return 1;
                }
            }
        }
        public int test2()
        {

            {
                switch (Utility.Random(2))
                {
                    default:
                    case 1: return 1;
                    case 2: return 2;
                }
            }
        }
        public LapisSeedBox(Serial serial)
            : base(serial)
        {
        }
        public override void GetContextMenuEntries(Mobile from, List<ContextMenuEntry> list)
        {
            base.GetContextMenuEntries(from, list);

            if (from.CheckAlive() && this.IsChildOf(from.Backpack))
                list.Add(new NameSeedBoxEntry(from, this));

            SetSecureLevelEntry.AddTo(from, this, list);
        }
        private void debugMakeDefault()
        {
            PlantType type;
            switch (Utility.Random(17))
            {
                case 0:
                    type = PlantType.CampionFlowers;
                    break;
                case 1:
                    type = PlantType.Poppies;
                    break;
                case 2:
                    type = PlantType.Snowdrops;
                    break;
                case 3:
                    type = PlantType.Bulrushes;
                    break;
                case 4:
                    type = PlantType.Lilies;
                    break;
                case 5:
                    type = PlantType.PampasGrass;
                    break;
                case 6:
                    type = PlantType.Rushes;
                    break;
                case 7:
                    type = PlantType.ElephantEarPlant;
                    break;
                case 8:
                    type = PlantType.Fern;
                    break;
                case 9:
                    type = PlantType.PonytailPalm;
                    break;
                case 10:
                    type = PlantType.SmallPalm;
                    break;
                case 11:
                    type = PlantType.CenturyPlant;
                    break;
                case 12:
                    type = PlantType.WaterPlant;
                    break;
                case 13:
                    type = PlantType.SnakePlant;
                    break;
                case 14:
                    type = PlantType.PricklyPearCactus;
                    break;
                case 15:
                    type = PlantType.BarrelCactus;
                    break;
                default:
                    type = PlantType.TribarrelCactus;
                    break;
            }
            PlantHue hue;
            switch (Utility.Random(18))
            {
                case 0:
                    hue = PlantHue.Red;
                    break;
                case 1:
                    hue = PlantHue.Blue;
                    break;
                case 2:
                    hue = PlantHue.Yellow;
                    break;
                case 3:
                    hue = PlantHue.Purple;
                    break;
                case 4:
                    hue = PlantHue.Green;
                    break;
                case 5:
                    hue = PlantHue.Orange;
                    break;
                case 6:
                    hue = PlantHue.BrightRed;
                    break;
                case 7:
                    hue = PlantHue.BrightBlue;
                    break;
                case 8:
                    hue = PlantHue.BrightYellow;
                    break;
                case 9:
                    hue = PlantHue.BrightPurple;
                    break;
                case 10:
                    hue = PlantHue.BrightGreen;
                    break;
                case 11:
                    hue = PlantHue.BrightOrange;
                    break;
                case 12:
                    hue = PlantHue.Black;
                    break;
                case 13:
                    hue = PlantHue.White;
                    break;
                case 14:
                    hue = PlantHue.Pink;
                    break;
                case 15:
                    hue = PlantHue.Magenta;
                    break;
                case 16:
                    hue = PlantHue.Aqua;
                    break;
                case 17:
                    hue = PlantHue.FireRed;
                    break;
                default:
                    hue = PlantHue.Plain;
                    break;
            }
            PlantData pd = new PlantData(type, hue);
            this.seedList.Add(pd);
        }

        private void debugMakePeculiar()
        {
            PlantType type;
            switch (Utility.Random(18))
            {
                case 0:
                    type = PlantType.Cactus;
                    break;
                case 1:
                    type = PlantType.FlaxFlowers;
                    break;
                case 2:
                    type = PlantType.FoxgloveFlowers;
                    break;
                case 3:
                    type = PlantType.HopsEast;
                    break;
                case 4:
                    type = PlantType.OrfluerFlowers;
                    break;
                case 5:
                    type = PlantType.CypressTwisted;
                    break;
                case 6:
                    type = PlantType.HedgeShort;
                    break;
                case 7:
                    type = PlantType.JuniperBush;
                    break;
                case 8:
                    type = PlantType.SnowdropPatch;
                    break;
                case 9:
                    type = PlantType.Cattails;
                    break;
                case 10:
                    type = PlantType.PoppyPatch;
                    break;
                case 11:
                    type = PlantType.SpiderTree;
                    break;
                case 12:
                    type = PlantType.WaterLily;
                    break;
                case 13:
                    type = PlantType.CypressStraight;
                    break;
                case 14:
                    type = PlantType.HedgeTall;
                    break;
                case 15:
                    type = PlantType.HopsSouth;
                    break;
                case 16:
                    type = PlantType.SugarCanes;
                    break;
                default:
                    type = PlantType.CocoaTree;
                    break;
            }
            PlantHue hue;
            switch (Utility.Random(7))
            {
                case 0:
                    hue = PlantHue.Black;
                    break;
                case 1:
                    hue = PlantHue.White;
                    break;
                case 2:
                    hue = PlantHue.FireRed;
                    break;
                case 3:
                    hue = PlantHue.Pink;
                    break;
                case 4:
                    hue = PlantHue.Magenta;
                    break;
                case 5:
                    hue = PlantHue.Aqua;
                    break;
                default:
                    hue = PlantHue.Plain;
                    break;
            }
            PlantData pd = new PlantData(type, hue);
            this.seedList.Add(pd);
        }
        private void debugMakeBonsai()
        {
            PlantType type;
            switch (Utility.Random(8))
            {
                case 0:
                    type = PlantType.CommonGreenBonsai;
                    break;
                case 1:
                    type = PlantType.CommonPinkBonsai;
                    break;
                case 2:
                    type = PlantType.UncommonGreenBonsai;
                    break;
                case 3:
                    type = PlantType.UncommonPinkBonsai;
                    break;
                case 4:
                    type = PlantType.RareGreenBonsai;
                    break;
                case 5:
                    type = PlantType.RarePinkBonsai;
                    break;
                case 6:
                    type = PlantType.ExceptionalBonsai;
                    break;
                default:
                    type = PlantType.ExoticBonsai;
                    break;
            }
            PlantData pd = new PlantData(type, PlantHue.Plain);
            this.seedList.Add(pd);
        }
        /**
         * 登録されている種の総数を返します。
         */
        public int getTotalCount()
        {
            return this.seedList.Count;
        }
        /**
         * 指定したタイプの種の総数を返します。
         */
        public int getSeedCount(PlantType pType)
        {
            int count = 0;
            for (int i = 0; i < seedList.Count; i++)
            {
                PlantData plant = (PlantData)seedList[i];
                if (plant.getPlantType() == pType)
                {
                    count++;
                }
            }
            return count;
        }

        /**
         * 指定したタイプ及び色の種の総数を返します。
         */
        public int getColorSeedCount(PlantType pType, PlantHue pHue)
        {
            int count = 0;
            for (int i = 0; i < seedList.Count; i++)
            {
                PlantData plant = (PlantData)seedList[i];
                //Console.WriteLine("plant.PlantHue={0} pHue={1}", plant.PlantHue, pHue);
                if (plant.getPlantType() == pType && plant.getPlantHue() == pHue)
                {
                    count++;
                }
            }
            return count;
        }

        public override void OnDoubleClick(Mobile from)
        {
            if (from.FindGump(typeof(LapisSeedBox.InternalGump)) == null)
                from.SendGump(new InternalGump(this, 0));
        }
        public override bool OnDragDrop(Mobile from, Item dropped)
        {

            // ドロップされたアイテムが種ではない
            if (!(dropped is Seed))
            {
                from.SendMessage("そういうイジワルはしちゃあかんです！！");
                return false;
            }

            // 植物データに変換
            PlantData pd = null;
            // 種チェック
            int stack = 0;
            if (dropped is Seed)
            {
                // 登録数MAX(以上はありえないけど念のため)
                if (getTotalCount() >= MAX_COUNT)
                {
                    from.SendMessage("これ以上追加できません。");
                    return false;
                }
                // 種はスタックするのでスタック数を考慮したMAX数チェック
                stack = dropped.Amount;
                // 現在の登録数＋スタック数が登録数MAX以上
                if((getTotalCount() + stack) > MAX_COUNT)
                {
                    from.SendMessage("これ以上追加できません。");
                    return false;
                }

                // ドロップされた種のHueがNoneである場合（まずありえない）
                if (((Seed)dropped).PlantHue == PlantHue.None)
                {
                    // Plainを代入
                    pd = new PlantData(((Seed)dropped).PlantType, PlantHue.Plain);
                }
                else
                {
                    pd = new PlantData(((Seed)dropped).PlantType, ((Seed)dropped).PlantHue);
                }

            }
            // ありえないだろうけど一応
            if(pd == null)
            {
                return false;
            }
            // スタック数分追加する
            for(int i = 0; i < stack; i++)
            {
                seedList.Add(pd);
            }
            from.SendMessage("種を追加しました！");
            if (this.getTotalCount() > 0)
            {
                this.ItemID = 0x4B59;
            }
            dropped.Delete();
            // プロパティを更新
            this.InvalidateProperties();
            // バインダーのガンプを表示していたら閉じる
            from.CloseGump(typeof(InternalGump));
            // バインダーを開く
            from.SendGump(new InternalGump(this, 1));
            return true;
        }

         /**
         * 現在のメニューページを返します。
         */
        public int getNowMenuPage()
        {
            return nowMenuPage;
        }
        /**
         * 指定したのメニューページへ進みます
         */
        public void gotoMenuPage(int menuPage)
        {
            this.nowMenuPage = menuPage;
        }
        /**
         * 現在のメインページを返します。
         */
        public int getNowPage()
        {
            return nowPage;
        }
        /**
         * 指定したのメインページへ進みます
         */
        public void gotoPage(int page)
        {
            this.nowPage = page;
        }
        /**
         * 種を復元します。
         */
        public void releseSeed(Mobile mob, PlantType pType, PlantHue pHue)
        {
            if (LapisSeedBox.isDebug)
            {
            }
            // 重量判定
            if ((mob.MaxWeight - mob.TotalWeight) < 50)
            {
                mob.SendMessage("バックパックの重量に余裕がありません。");
                return;
            }
            // 所持数判定
            if (mob.Backpack.TotalItems > 124)
            {
                mob.SendMessage("バックパックの空きに余裕がありません。");
                return;
            }
            Seed pi = null;
            for (int i = 0; i < seedList.Count; i++)
            {
                PlantData data = (PlantData)seedList[i];
                // 選択されたタイプ及び色をリストから検索
                if (data.getPlantType() == pType && data.getPlantHue() == pHue)
                {
                    // 条件に合致したら代入
                    pi = new Seed();
                    pi.PlantType = data.getPlantType();
                    pi.PlantHue = data.getPlantHue();
                    pi.ShowType = true;
                    // リストから削除
                    seedList.RemoveAt(i);
                    //処理を終える
                    break;
                }
            }
            // 条件に合致した植物がなかった場合
            if (pi == null)
            {
                mob.SendMessage("該当の種がありません。");
                return;
            }
            // 存在する場合はバックパックに復元
            mob.SendMessage("種を取り出しました。");
            if (this.getTotalCount() == 0)
            {
                this.ItemID = 0x4B58;
            }
            // プロパティを更新
            this.InvalidateProperties();
            // Rev.1(S) 取り出し方変更
            // mob.Backpack.AddItem(pi);
            mob.Backpack.TryDropItem(mob, pi, true);
            // Rev.1(E)
        }

        /**
         * メニューリスト(日本語）を返します
         */
        public String[] getMenuPlantListName(int category)
        {
            return this.menuPlantListName[category];
        }
        /**
         * メニューのPlantTypeを返します
         */
        public PlantType[][] getMenuPlantList()
        {
            return this.menuPlantList;
        }

        /**
         * カラーリストを返します
         */
        public PlantHue[] getShowColor(int category)
        {
            return this.showColor[category];
        }

        public override void GetProperties(ObjectPropertyList list)
        {
            base.GetProperties(list);
            list.Add(1062344, this.seedList.Count.ToString() + "/" + MAX_COUNT);
            if (this.m_seedBoxName != null && this.m_seedBoxName.Length > 0)
                list.Add("名前 : " + this.m_seedBoxName); // Book Name: ~1_val~
        }

        private class InternalGump : Gump
        {
            private int mainPageX = 260;
            private int nKind = 0;

            // リストから割り出した必要ページ数
            private int page = 0;

            // 1ページあたりの最大表示数
            private static readonly int PAGE_MAX_DISP = 10;
            // 半ページあたりの最大表示数
            private static readonly int HALF_PAGE_MAX_DISP = 5;
            // 最大ページ数
            private static readonly int PAGE_MAX = 3;


            private LapisSeedBox seedBox;
            public InternalGump(LapisSeedBox box, int nKind)
                : base(150, 50)
            {
                this.seedBox = box;
                this.AddPage(0);
                // 背景
                this.AddImageTiled(26, 26, 560, 480, 0x0DB0);

                // 左上
                this.AddImage(0, 0, 0x0DAC);                   // width26 height26
                // 上
                this.AddImageTiled(26, 0, 560, 26, 0x0DAD);
                // 右上
                this.AddImage(560, 0, 0x0DAE);        // width26 height26
                // 左
                this.AddImageTiled(0, 26, 26, 480 - 26, 0x0DAF);
                // 右
                this.AddImageTiled(560, 26, 26, 480 - 26, 0x0DB1);

                // タイトルから少し下に横線
                this.AddImageTiled(10, 80, 560, 26, 0x0DB3);

                // メニュー区切り
                this.AddImageTiled(200, 100, 26, 400, 0x0DB1);

                // 下
                this.AddImageTiled(26, 480, 560 - 26, 26, 0x0DB3);
                // 左下
                this.AddImage(0, 480, 0x0DB2);
                // 右下
                this.AddImage(560, 480, 0x0DB4);

                this.AddHtml(20, 30, 180, 20, "<BASEFONT COLOR =#006400><CENTER><BIG>ラピス民のSeed Box", false, false);
                this.AddItem(68, 50, 0x0C98);
                this.AddItem(530, 55, 0x11CB);
                this.AddButton(230, 30, 0x0837, 0x0838, 101, GumpButtonType.Reply, 0);
                this.AddHtml(230 + 25, 27, 200, 20, "旧植物", false, false);
                this.AddButton(230, 50, 0x0837, 0x0838, 102, GumpButtonType.Reply, 0);
                this.AddHtml(230 + 25, 47, 200, 20, "新植物", false, false);
                this.AddButton(230, 70, 0x0837, 0x0838, 103, GumpButtonType.Reply, 0);
                this.AddHtml(230 + 25, 67, 200, 20, "盆栽", false, false);
                for (int i = 0; i < this.seedBox.getMenuPlantListName(this.seedBox.getNowMenuPage()).Length; i++)
                {
                    this.AddButton(30, 85 + (20 * (i + 1)), 0x0837, 0x0838, (i + 1), GumpButtonType.Reply, 0);
                    PlantType pt = this.seedBox.getMenuPlantList()[this.seedBox.getNowMenuPage()][i];
                    // 現在登録されているリストから該当種の総数を取得
                    int count = this.seedBox.getSeedCount(pt);
                    String text = this.seedBox.getMenuPlantListName(this.seedBox.getNowMenuPage())[i] + "(" + count + ")";
                    this.AddHtml(55, 82 + (20 * (i + 1)), 200, 20, text, false, false);
                }
                // 
                if (this.seedBox.getNowMenuPage() != 0 && this.seedBox.getNowPage() != 0)
                {
                    int offset = 25;
                    this.AddImageTiled(270 + offset, 105, 200, 200, 0x248A);

                    this.AddImageTiled(270 + offset, 100, 200, 4, 0x248D);
                    this.AddImageTiled(270 + offset, 305, 200, 4, 0x248D);
                    this.AddImageTiled(270 + offset, 100, 4, 200, 0x248B);
                    this.AddImageTiled(470 + offset, 100, 4, 200, 0x248B);

                    // 選択された種のタイプを取得
                    PlantType pt = this.seedBox.getMenuPlantList()[this.seedBox.getNowMenuPage()][this.seedBox.getNowPage() - 1];
                    PlantTypeInfo info = PlantTypeInfo.GetInfo(pt);
                    Rectangle2D b = ItemBounds.Table[info.ItemID];

                    this.AddItem((370 + offset) - b.Width / 2 - b.X, 215 - b.Height / 2 - b.Y, info.ItemID);

                    // 取得ボタンの描画
                    PlantHue[] hue = this.seedBox.getShowColor(this.seedBox.getNowMenuPage());
                    // 旧植物の場合
                    if (this.seedBox.getNowMenuPage() == 1)
                    {
                        for (int i = 0; i < hue.Length; i++)
                        {
                            int count = this.seedBox.getColorSeedCount(pt, hue[i]);
                            String text = count + " " + hue[i].ToString();
                            if (i < 7)
                            {
                                this.AddButton(230, 295 + (20 * (i + 1)), 0x5787, 0x5787, (i + 200), GumpButtonType.Reply, 0);
                                this.AddHtml(250, 292 + (20 * (i + 1)), 200, 20, text, false, false);
                            }
                            else if (i >= 7 && i < 13)
                            {
                                this.AddButton(330, 295 + (20 * ((i - 6) + 1)), 0x5787, 0x5787, (i + 200), GumpButtonType.Reply, 0);
                                this.AddHtml(350, 292 + (20 * ((i - 6) + 1)), 200, 20, text, false, false);
                            }
                            else
                            {
                                this.AddButton(470, 295 + (20 * ((i - 12) + 1)), 0x5787, 0x5787, (i + 200), GumpButtonType.Reply, 0);
                                this.AddHtml(490, 292 + (20 * ((i - 12) + 1)), 200, 20, text, false, false);
                            }
                        }
                    }
                    // 新植物の場合
                    else if (this.seedBox.getNowMenuPage() == 2)
                    {
                        for (int i = 0; i < hue.Length; i++)
                        {
                            int count = this.seedBox.getColorSeedCount(pt, hue[i]);
                            String text = count + " " + hue[i].ToString();
                            if (i < 7)
                            {
                                this.AddButton(230, 295 + (20 * (i + 1)), 0x5787, 0x5787, (i + 200), GumpButtonType.Reply, 0);
                                this.AddHtml(250, 292 + (20 * (i + 1)), 200, 20, text, false, false);
                            }
                        }
                    }
                    //盆栽の場合
                    else if (this.seedBox.getNowMenuPage() == 3)
                    {
                        for (int i = 0; i < hue.Length; i++)
                        {
                            int count = this.seedBox.getColorSeedCount(pt, hue[i]);
                            String text = count + " " + hue[i].ToString();
                            if (i < 7)
                            {
                                this.AddButton(230, 295 + (20 * (i + 1)), 0x5787, 0x5787, (i + 200), GumpButtonType.Reply, 0);
                                this.AddHtml(250, 292 + (20 * (i + 1)), 200, 20, text, false, false);
                            }
                        }
                    }

                }

            }

            public override void OnResponse(NetState sender, RelayInfo info)
            {
                int button = info.ButtonID;
                Mobile mob = sender.Mobile;

                switch (button)
                {
                    case 101:
                        this.seedBox.gotoMenuPage(1);
                        this.seedBox.gotoPage(0);
                        mob.CloseGump(typeof(InternalGump));
                        mob.SendGump(new InternalGump(this.seedBox, 1));
                        break;
                    case 102:
                        this.seedBox.gotoMenuPage(2);
                        this.seedBox.gotoPage(0);
                        mob.CloseGump(typeof(InternalGump));
                        mob.SendGump(new InternalGump(this.seedBox, 1));
                        break;
                    case 103:
                        this.seedBox.gotoMenuPage(3);
                        this.seedBox.gotoPage(0);
                        mob.CloseGump(typeof(InternalGump));
                        mob.SendGump(new InternalGump(this.seedBox, 1));
                        break;
                    default:
                        if (this.seedBox.getNowMenuPage() == 1 && button > 0 && button < 18)
                        {
                            this.seedBox.gotoPage(button);
                            mob.CloseGump(typeof(InternalGump));
                            mob.SendGump(new InternalGump(this.seedBox, 1));
                        }
                        else if (this.seedBox.getNowMenuPage() == 2 && button > 0 && button < 20)
                        {
                            this.seedBox.gotoPage(button);
                            mob.CloseGump(typeof(InternalGump));
                            mob.SendGump(new InternalGump(this.seedBox, 1));
                        }
                        else if (this.seedBox.getNowMenuPage() == 3 && button > 0 && button < 9)
                        {
                            this.seedBox.gotoPage(button);
                            mob.CloseGump(typeof(InternalGump));
                            mob.SendGump(new InternalGump(this.seedBox, 1));
                        }
                        else if (this.seedBox.getNowMenuPage() == 1 && button >= 200)
                        {
                            PlantType pt = this.seedBox.getMenuPlantList()[this.seedBox.getNowMenuPage()][this.seedBox.getNowPage() - 1];
                            PlantHue hue = this.seedBox.getShowColor(this.seedBox.getNowMenuPage())[button - 200];
                            this.seedBox.releseSeed(mob, pt, hue);
                            mob.CloseGump(typeof(InternalGump));
                            mob.SendGump(new InternalGump(this.seedBox, 1));
                        }
                        else if (this.seedBox.getNowMenuPage() == 2 && button >= 200)
                        {
                            PlantType pt = this.seedBox.getMenuPlantList()[this.seedBox.getNowMenuPage()][this.seedBox.getNowPage() - 1];
                            PlantHue hue = this.seedBox.getShowColor(this.seedBox.getNowMenuPage())[button - 200];
                            this.seedBox.releseSeed(mob, pt, hue);
                            mob.CloseGump(typeof(InternalGump));
                            mob.SendGump(new InternalGump(this.seedBox, 1));
                        }
                        else if (this.seedBox.getNowMenuPage() == 3 && button >= 200)
                        {
                            PlantType pt = this.seedBox.getMenuPlantList()[this.seedBox.getNowMenuPage()][this.seedBox.getNowPage() - 1];
                            PlantHue hue = this.seedBox.getShowColor(this.seedBox.getNowMenuPage())[button - 200];
                            this.seedBox.releseSeed(mob, pt, hue);
                            mob.CloseGump(typeof(InternalGump));
                            mob.SendGump(new InternalGump(this.seedBox, 1));
                        }
                        break;
                }
            }
        }

        private class NameSeedBoxEntry : ContextMenuEntry
        {
            private readonly Mobile m_From;
            private readonly LapisSeedBox m_SeedBox;
            public NameSeedBoxEntry(Mobile from, LapisSeedBox seedBox)
                : base(6216)
            {
                this.m_From = from;
                this.m_SeedBox = seedBox;
            }

            public override void OnClick()
            {
                if (this.m_From.CheckAlive() && this.m_SeedBox.IsChildOf(this.m_From.Backpack))
                {
                    this.m_From.Prompt = new NameSeedBoxPrompt(this.m_SeedBox);
                    this.m_From.SendMessage("新しい名前を付けてください。"); // Type in the new name of the book:
                }
            }
        }
        private class NameSeedBoxPrompt : Prompt
        {
            private readonly LapisSeedBox m_SeedBox;
            public NameSeedBoxPrompt(LapisSeedBox seedBox)
            {
                this.m_SeedBox = seedBox;
            }

            public override void OnResponse(Mobile from, string text)
            {
                if (text.Length > 40)
                    text = text.Substring(0, 40);

                if (from.CheckAlive() && this.m_SeedBox.IsChildOf(from.Backpack))
                {
                    this.m_SeedBox.seedBoxName = Utility.FixHtml(text.Trim());

                    from.SendMessage("名前を変更しました。"); // The bulk order book's name has been changed.
                }
            }

            public override void OnCancel(Mobile from)
            {
            }
        }

        private class PlantData
        {
            private readonly PlantType plantType;
            private readonly PlantHue plantHue;

            public PlantData(PlantType pt, PlantHue ph)
            {
                this.plantType = pt;
                this.plantHue = ph;
            }

            public PlantData(GenericReader reader)
            {
                int version = reader.ReadInt();
                this.plantType = (PlantType)reader.ReadInt();
                this.plantHue = (PlantHue)reader.ReadInt();
            }

            public PlantType getPlantType()
            {
                return this.plantType;
            }
            public PlantHue getPlantHue()
            {
                return this.plantHue;
            }

            public void Serialize(GenericWriter writer)
            {
                writer.Write(0); // version
                writer.Write((int)this.plantType);
                writer.Write((int)this.plantHue);
            }
        }

        public override void Serialize(GenericWriter writer)
        {
            base.Serialize(writer);

            writer.Write((int)0); // version
            writer.Write((int)m_Level); // セキュアレベル
            writer.Write((int)this.seedList.Count); // 総数
            for (int i = 0; i < this.seedList.Count; ++i)
            {
                object obj = this.seedList[i];
                ((PlantData)obj).Serialize(writer);
            }
            writer.Write(this.seedBoxName); // 名前
            writer.Write(this.Hue); // 色
        }


        public override void Deserialize(GenericReader reader)
        {
            base.Deserialize(reader);
            int version = reader.ReadInt();
            this.m_Level = (SecureLevel)reader.ReadInt();

            int count = reader.ReadInt();
            this.seedList = new ArrayList();
            for (int i = 0; i < count; i++)
            {
　　            PlantData pd = new PlantData(reader);
                this.seedList.Add(pd);
            }
            this.seedBoxName = reader.ReadString();
            this.Hue = reader.ReadInt();
        }
    }
}
